==> phpunit_10.0.12.orig.tar.xz: phpunit-10.0.12/tests/unit/Event/Events/Test/HookMethod/BeforeFirstTestMethodErroredTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Event\Test;

use function array_values;
use function explode;
use Exception;
use PHPUnit\Event\AbstractEventTestCase;
use PHPUnit\Event\Code;
use PHPUnit\Event\Code\Throwable;
use PHPUnit\Framework\Attributes\CoversClass;

#[CoversClass(BeforeFirstTestMethodErrored::class)]
final class BeforeFirstTestMethodErroredTest extends AbstractEventTestCase
{
    public function testConstructorSetsValues(): void
    {
        $telemetryInfo = $this->telemetryInfo();
        $testClassName = self::class;
        $calledMethod  = new Code\ClassMethod(...array_values(explode(
            '::',
            __METHOD__
        )));
        $throwable = Throwable::from(new Exception('message'));

        $event = new BeforeFirstTestMethodErrored(
            $telemetryInfo,
            $testClassName,
            $calledMethod,
            $throwable
        );

        $this->assertSame($telemetryInfo, $event->telemetryInfo());
        $this->assertSame($testClassName, $event->testClassName());
        $this->assertSame($calledMethod, $event->calledMethod());
        $this->assertSame($throwable, $event->throwable());
        $this->assertSame('Before First Test Method Errored (PHPUnit\Event\Test\BeforeFirstTestMethodErroredTest::testConstructorSetsValues)
message', $event->asString());
    }
}

==> phpunit_10.1.2.orig.tar.xz: phpunit-10.1.2/tests/unit/Event/Events/Test/HookMethod/BeforeFirstTestMethodErroredTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Event\Test;

use Exception;
use PHPUnit\Event\AbstractEventTestCase;
use PHPUnit\Event\Code;
use PHPUnit\Framework\Attributes\CoversClass;
use PHPUnit\Framework\Attributes\Small;

#[CoversClass(BeforeFirstTestMethodErrored::class)]
#[Small]
final class BeforeFirstTestMethodErroredTest extends AbstractEventTestCase
{
    public function testConstructorSetsValues(): void
    {
        $telemetryInfo = $this->telemetryInfo();
        $testClassName = 'Test';
        $calledMethod  = $this->calledMethod();
        $throwable     = Code\ThrowableBuilder::from(new Exception('message'));

        $event = new BeforeFirstTestMethodErrored(
            $telemetryInfo,
            $testClassName,
            $calledMethod,
            $throwable
        );

        $this->assertSame($telemetryInfo, $event->telemetryInfo());
        $this->assertSame($testClassName, $event->testClassName());
        $this->assertSame($calledMethod, $event->calledMethod());
        $this->assertSame($throwable, $event->throwable());
    }

    public function testCanBeRepresentedAsString(): void
    {
        $event = new BeforeFirstTestMethodErrored(
            $this->telemetryInfo(),
            'Test',
            $this->calledMethod(),
            Code\ThrowableBuilder::from(new Exception('message'))
        );

        $this->assertSame(
            <<<'EOT'
Before First Test Method Errored (HookClass::hookMethod)
message
EOT,
            $event->asString()
        );
    }

    private function calledMethod(): Code\ClassMethod
    {
        return new Code\ClassMethod('HookClass', 'hookMethod');
    }
}
